pro g_remake_psf, gauss, resid, psfrad, psf_image, psfmag, fit_rad
;+
; NAME:
;       RDPSF
; PURPOSE:
;       Read the FITS file created by GETPSF in the DAOPHOT sequence
; EXPLANATION:
;       Combines the Gaussian with the residuals to create an output PSF array.
;
; CALLING SEQUENCE:
;       RDPSF, PSF, HPSF, [ PSFname]
;
; OPTIONAL INPUTS
;       PSFname - string giving the name of the FITS file containing the PSF
;               residuals
;
; OUTPUTS
;       psf - array containing the actual PSF
;       hpsf - header associated with psf
;
; PROCEDURES CALLED:
;       DAO_VALUE(), MAKE_2D, SXADDPAR, READFITS(), SXPAR()
; REVISION HISTORY:
;       Written W. Landsman              December, 1988
;       Checked for IDL Version 2, J. Isensee & J. Hill, December, 1990
;       Converted to IDL V5.0   W. Landsman   September 1997
;-
 npsf = 2*psfrad+1             ;Width of output array containing PSF
 psf_image = fltarr(npsf,npsf)       ;Create output array
 pure_resid = fltarr(npsf, npsf)	 ; residuals
 dx = indgen(npsf) - psfrad    ;Vector gives X distance from center of array
 dy = dx                       ;Ditto for dy
 make_2d,dx,dy                 ;Now have X and Y values for each pixel in
;                              the output array
;print, dx

psf_image = psf_image + dao_value(dx,dy,gauss,resid) ;Compute DAOPHOT value at each point
zero_gauss = gauss
zero_gauss[0] = 0.0
pure_resid = pure_resid + dao_value(dx,dy,zero_gauss,resid) ; compute DAO residuals only
;
;	note that psf_image array is smaller than resid array
;
;print, psf_image
;
;	compute PSF mag from gaussian and residuals
;
rad = sqrt(dx * dx + dy * dy)			; /2. - no 2, since dx,dy in dao_value are "full" pixels
ind_f = WHERE(rad le fit_rad,count_f)
;ind_p = WHERE(rad le psfrad, count_p)
if(count_f gt 0) then begin
	sum_resid_f = TOTAL(pure_resid[ind_f])	;	/4.
	sum_all_f = TOTAL(psf_image[ind_f])/4.
endif
;if(count_p gt 0) then begin
;	sum_resid_p = TOTAL(pure_resid[ind_p])/4.
;	sum_all_p = TOTAL(psf_image[ind_p])/4.
;endif
;
;	if sum of residuals < 0, then reset to zero and push up gaussian by ave
;
if(sum_resid_f lt 0.0) then begin
	print, 'G_REMAKE_PSF: warning - residuals net negative counts - resetting to zero'
	zz = median_filtered_mean(pure_resid[ind_f])
	;
	sum_resid_f = 0.0
	gauss[0] = gauss[0] - zz[0]
endif
;
;	next, compute psf mag from gaussian sum and resid sum
;
integral_gauss = psf_image * 0.0
integral_gauss = integral_gauss + dao_value(dx,dy,gauss,resid*0.0)
;
integral_gauss_sum = TOTAL(integral_gauss)
;
gauss_sum = gauss[0] * !DPI * 2.0 * abs(gauss[3] * gauss[4])
;
;print, "G_REMAKE_PSF: gauss_sum = ",gauss_sum," integral gauss sum = ",integral_gauss_sum," sum_resid = ",sum_resid
;
total_counts = sum_resid_f + gauss_sum
;
;PSFmag = 25.0 - 2.5d0 * alog10 (total_counts)
;if(abs(PSFmag - 15.0) gt 0.005) then begin
;	print, 'G_REMAKE_PSF: > 0.5% difference in PSFmag = ',PSFmag,' rescaling PSF'
;	g_mag = 25.0 - 2.5d0 * alog10(gauss_sum)
;	r_mag = 25.0 - 2.5d0 * alog10(sum_resid_f)
;	print, '   Gauss mag, Resid mag = ',g_mag, r_mag
;	delta_mag = 15.0d0 - PSFmag
;	scale = 10.0^(-0.4*delta_mag)
;	gauss[0] = gauss[0] * scale
;	resid = resid * scale
	PSFmag = 15.0
;endif
;
if(~FINITE(PSFmag)) then begin
	print, "G_REMAKE_PSF: ERROR - psfmag = ",PSFmag," so stopping"
	print, "gauss_sum = ",gauss_sum,"  resid_sum = ",sum_resid,"   total_counts = ",total_counts
	stop
endif
;
;print, "G_REMAKE_PSF: calculated PSFmag = ",PSFmag
;
end
